==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/zh_TW.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "文件",
    "Can't create document" : "無法建立文件",
    "You don't have permission to rename this document" : "您沒有重新命名的權限",
    "Directory saved successfully." : "資料夾已成功儲存.",
    "An error occurred while changing directory." : "變更資料夾時發生錯誤.",
    "Saved" : "已儲存",
    "Saving..." : "儲存中...",
    "Failed to load documents." : "載入文件失敗",
    "No connection to server. Trying to reconnect." : "未連接伺服器，嘗試連線中。",
    "Save" : "儲存",
    "Loading documents..." : "讀取文件中...",
    "'.' is an invalid file name." : "'.' 是不合法的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "檔名不合法，不允許 \\ / < > : \" | ? * 字元",
    "Align Left" : "靠左對齊",
    "Alignment" : "文字對齊",
    "Align Right" : "靠右對齊",
    "Annotate" : "註釋",
    "Background" : "背景",
    "Bold" : "粗體",
    "Bottom" : "底部",
    "Cancel" : "取消",
    "Center" : "中央",
    "Clone" : "複製",
    "Clone this Style" : "複製樣式",
    "Close" : " 關閉",
    "Color" : "色彩",
    "Create" : "建立",
    "Decrease Indent" : "減少縮排",
    "Default Style" : "預設樣式",
    "Delete" : "刪除",
    "Family" : "親人",
    "Font" : "字型",
    "Font Effects" : "字型效果",
    "Format" : "格式",
    "Increase Indent" : "增加縮排",
    "Insert Image" : "插入圖片",
    "Invite Members" : "邀請會員",
    "Italic" : "斜體",
    "Loading" : "載入中",
    "Members" : "會員",
    "New Name:" : "新名稱：",
    "OK" : "確定",
    "Open" : "開啟",
    "Options" : "選項",
    "Paragraph..." : "段落...",
    "Paragraph Styles" : "段落樣式",
    "Redo" : "重做",
    "Size" : "大小",
    "Style" : "樣式",
    "Text" : "文字",
    "Top" : "頂端",
    "Underline" : "下底線",
    "Undo" : "復原",
    "Unknown Author" : "作者不明",
    "Edit" : "編輯",
    "Share" : "分享",
    "guest" : "訪客",
    "Local" : "本地",
    "External" : "外部",
    "Disabled" : "已停用",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "伺服器網址",
    "Apply and test" : "套用並測試",
    "New document" : "新文件",
    "Upload (max. %s)" : "上傳（至多 %s）",
    "Upload" : "上傳",
    "Save new documents to" : "儲存新檔案至",
    "Wrong password. Please retry." : "密碼錯誤，請重新嘗試。",
    "Password" : "密碼",
    "Guest %s" : "訪客 %s",
    "Advanced feature-set" : "進階功能",
    "(Unstable)" : "（不穩定）"
},
"nplurals=1; plural=0;");

==> owncloud-app-documents-1%3A8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/zh_TW.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "文件",
    "Can't create document" : "無法建立文件",
    "You don't have permission to rename this document" : "您沒有重新命名的權限",
    "Directory saved successfully." : "資料夾已成功儲存.",
    "An error occurred while changing directory." : "變更資料夾時發生錯誤.",
    "Saved" : "已儲存",
    "Saving..." : "儲存中...",
    "Failed to load documents." : "載入文件失敗",
    "No connection to server. Trying to reconnect." : "未連接伺服器，嘗試連線中。",
    "Save" : "儲存",
    "Loading documents..." : "讀取文件中...",
    "'.' is an invalid file name." : "'.' 是不合法的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "檔名不合法，不允許 \\ / < > : \" | ? * 字元",
    "Align Left" : "靠左對齊",
    "Alignment" : "文字對齊",
    "Align Right" : "靠右對齊",
    "Annotate" : "註釋",
    "Background" : "背景",
    "Bold" : "粗體",
    "Bottom" : "底部",
    "Cancel" : "取消",
    "Center" : "中央",
    "Clone" : "複製",
    "Clone this Style" : "複製樣式",
    "Close" : " 關閉",
    "Color" : "色彩",
    "Create" : "建立",
    "Decrease Indent" : "減少縮排",
    "Default Style" : "預設樣式",
    "Delete" : "刪除",
    "Family" : "親人",
    "Font" : "字型",
    "Font Effects" : "字型效果",
    "Format" : "格式",
    "Increase Indent" : "增加縮排",
    "Insert Image" : "插入圖片",
    "Invite Members" : "邀請會員",
    "Italic" : "斜體",
    "Loading" : "載入中",
    "Members" : "會員",
    "New Name:" : "新名稱：",
    "OK" : "確定",
    "Open" : "開啟",
    "Options" : "選項",
    "Paragraph..." : "段落...",
    "Paragraph Styles" : "段落樣式",
    "Redo" : "重做",
    "Size" : "大小",
    "Style" : "樣式",
    "Text" : "文字",
    "Top" : "頂端",
    "Underline" : "下底線",
    "Undo" : "復原",
    "Unknown Author" : "作者不明",
    "Shared" : "已分享",
    "Error" : "錯誤",
    "Error while sharing" : "分享時發生錯誤",
    "Error while unsharing" : "取消分享時發生錯誤",
    "Error while changing permissions" : "修改權限時發生錯誤",
    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}",
    "Shared with you by {owner}" : "{owner} 已經和您分享",
    "Share" : "分享",
    "Share link" : "分享連結",
    "The public link will expire no later than {days} days after it is created" : "這個公開連結會在 {days} 天內失效",
    "Password protect" : "密碼保護",
    "Password" : "密碼",
    "Choose a password for the public link" : "為公開連結選一個密碼",
    "Email link to person" : "將連結 email 給別人",
    "Send" : "寄出",
    "Set expiration date" : "指定到期日",
    "Expiration" : "過期",
    "Expiration date" : "到期日",
    "An error occured. Please try again" : "發生錯誤，請重試",
    "Adding user..." : "新增使用者……",
    "group" : "群組",
    "remote" : "遠端",
    "Resharing is not allowed" : "不允許重新分享",
    "Shared in {item} with {user}" : "已和 {user} 分享 {item}",
    "Unshare" : "取消分享",
    "notify by email" : "以 email 通知",
    "can share" : "可分享",
    "can edit" : "可編輯",
    "access control" : "存取控制",
    "create" : "建立",
    "change" : "更動",
    "delete" : "刪除",
    "Password protected" : "受密碼保護",
    "Error unsetting expiration date" : "取消到期日設定失敗",
    "Error setting expiration date" : "設定到期日發生錯誤",
    "Sending ..." : "正在傳送…",
    "Email sent" : "Email 已寄出",
    "Warning" : "警告",
    "Edit" : "編輯",
    "guest" : "訪客",
    "Local" : "本地",
    "External" : "外部",
    "Disabled" : "已停用",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "伺服器網址",
    "Apply and test" : "套用並測試",
    "New document" : "新文件",
    "Upload (max. %s)" : "上傳（至多 %s）",
    "Upload" : "上傳",
    "Save new documents to" : "儲存新檔案至",
    "Wrong password. Please retry." : "密碼錯誤，請重新嘗試。",
    "Guest %s" : "訪客 %s",
    "Advanced feature-set" : "進階功能",
    "(Unstable)" : "（不穩定）"
},
"nplurals=1; plural=0;");
